==> d2l-0.13.0.tar.gz: d2l-0.13.0/README.md <==
# Dive into Deep Learning (D2L Book)

[![Build Status](http://ci.d2l.ai/job/d2l-en/job/master/badge/icon)](http://ci.d2l.ai/job/d2l-en/job/master/)

[Book website](https://d2l.ai/) | [STAT 157 Course at UC Berkeley, Spring 2019](http://courses.d2l.ai/berkeley-stat-157/index.html)

<h5 align="center"><i>The best way to understand deep learning is learning by doing.</i></h5>

<p align="center">
  <img width="200"  src="static/frontpage/_images/eq.jpg">
  <img width="200"  src="static/frontpage/_images/figure.jpg">
  <img width="200"  src="static/frontpage/_images/code.jpg">
  <img width="200"  src="static/frontpage/_images/notebook.gif">
</p>

This open-source book represents our attempt to make deep learning approachable, teaching you the concepts, the context, and the code. The entire book is drafted in Jupyter notebooks, seamlessly integrating exposition figures, math, and interactive examples with self-contained code.

Our goal is to offer a resource that could 
1. be freely available for everyone; 
1. offer sufficient technical depth to provide a starting point on the path to actually becoming an applied machine learning scientist; 
1. include runnable code, showing readers how to solve problems in practice; 
1. allow for rapid updates, both by us and also by the community at large; 
1. be complemented by a forum for interactive discussion of technical details and to answer questions.

<h5 align="center">Universities that use D2L as a textbook or a reference book</h5>
<p align="center">
  <img width="400"  src="static/frontpage/_images/map.png">
</p>

If you find this book useful, please star (★) this repository or cite this book using the following bibtex entry:

```
@book{zhang2020dive,
    title={Dive into Deep Learning},
    author={Aston Zhang and Zachary C. Lipton and Mu Li and Alexander J. Smola},
    note={\url{https://d2l.ai}},
    year={2020}
}
```

## Endorsements

> <p>"In less than a decade, the AI revolution has swept from research labs to broad industries to every corner of our daily life.  Dive into Deep Learning is an excellent text on deep learning and deserves attention from anyone who wants to learn why deep learning has ignited the AI revolution: the most powerful technology force of our time."</p>
> <b>&mdash; Jensen Huang, Founder and CEO, NVIDIA</b>

> <p>"This is a timely, fascinating book, providing with not only a comprehensive overview of deep learning principles but also detailed algorithms with hands-on programming code, and moreover, a state-of-the-art introduction to deep learning in computer vision and natural language processing. Dive into this book if you want to dive into deep learning!"</p>
> <b>&mdash; Jiawei Han, Michael Aiken Chair Professor, University of Illinois at Urbana-Champaign</b>

> <p>"This is a highly welcome addition to the machine learning literature, with a focus on hands-on experience implemented via the integration of Jupyter notebooks. Students of deep learning should find this invaluable to become proficient in this field."</p>
> <b>&mdash; Bernhard Schölkopf, Director, Max Planck Institute for Intelligent Systems</b>

## Contribute ([learn how](https://d2l.ai/chapter_appendix-tools-for-deep-learning/contributing.html))

This open source book has benefited from pedagogical suggestions, typo corrections, and other improvements from community contributors. Your help is valuable for making the book better for everyone. We will [acknowledge](https://d2l.ai/chapter_preface/index.html#Acknowledgments) each D2L contributor in the book.

**Dear [D2L contributors](https://github.com/d2l-ai/d2l-en/graphs/contributors), please email your GitHub ID, name, and mailing address to d2lbook.en@gmail.com. Thanks.**

[Chinese version](https://github.com/d2l-ai/d2l-zh) | [Discuss and report issues](https://discuss.mxnet.io/)

## License Summary

This open source book is made available under the Creative Commons Attribution-ShareAlike 4.0 International License. See the LICENSE file.

The sample and reference code within this open source book is made available under a modified MIT license. See the LICENSE-SAMPLECODE file.

[Other Information](INFO.md)

==> d2l-0.14.2.tar.gz: d2l-0.14.2/README.md <==
# Dive into Deep Learning (D2L.ai)

[![Build Status](http://ci.d2l.ai/job/d2l-en/job/master/badge/icon)](http://ci.d2l.ai/job/d2l-en/job/master/)

[Book website](https://d2l.ai/) | [STAT 157 Course at UC Berkeley, Spring 2019](http://courses.d2l.ai/berkeley-stat-157/index.html)

<h5 align="center"><i>The best way to understand deep learning is learning by doing.</i></h5>

<p align="center">
  <img width="200"  src="static/frontpage/_images/eq.jpg">
  <img width="200"  src="static/frontpage/_images/figure.jpg">
  <img width="200"  src="static/frontpage/_images/code.jpg">
  <img width="200"  src="static/frontpage/_images/notebook.gif">
</p>

This open-source book represents our attempt to make deep learning approachable, teaching you the concepts, the context, and the code. The entire book is drafted in Jupyter notebooks, seamlessly integrating exposition figures, math, and interactive examples with self-contained code.

Our goal is to offer a resource that could
1. be freely available for everyone;
1. offer sufficient technical depth to provide a starting point on the path to actually becoming an applied machine learning scientist;
1. include runnable code, showing readers how to solve problems in practice;
1. allow for rapid updates, both by us and also by the community at large;
1. be complemented by a forum for interactive discussion of technical details and to answer questions.

<h5 align="center">Universities that use D2L as a textbook or a reference book</h5>
<p align="center">
  <img width="400"  src="static/frontpage/_images/map.png">
</p>

If you find this book useful, please star (★) this repository or cite this book using the following bibtex entry:

```
@book{zhang2020dive,
    title={Dive into Deep Learning},
    author={Aston Zhang and Zachary C. Lipton and Mu Li and Alexander J. Smola},
    note={\url{https://d2l.ai}},
    year={2020}
}
```

## Endorsements

> <p>"In less than a decade, the AI revolution has swept from research labs to broad industries to every corner of our daily life.  Dive into Deep Learning is an excellent text on deep learning and deserves attention from anyone who wants to learn why deep learning has ignited the AI revolution: the most powerful technology force of our time."</p>
> <b>&mdash; Jensen Huang, Founder and CEO, NVIDIA</b>

> <p>"This is a timely, fascinating book, providing with not only a comprehensive overview of deep learning principles but also detailed algorithms with hands-on programming code, and moreover, a state-of-the-art introduction to deep learning in computer vision and natural language processing. Dive into this book if you want to dive into deep learning!"</p>
> <b>&mdash; Jiawei Han, Michael Aiken Chair Professor, University of Illinois at Urbana-Champaign</b>

> <p>"This is a highly welcome addition to the machine learning literature, with a focus on hands-on experience implemented via the integration of Jupyter notebooks. Students of deep learning should find this invaluable to become proficient in this field."</p>
> <b>&mdash; Bernhard Schölkopf, Director, Max Planck Institute for Intelligent Systems</b>


## Contribute ([learn how](https://d2l.ai/chapter_appendix-tools-for-deep-learning/contributing.html))

This open source book has benefited from pedagogical suggestions, typo corrections, and other improvements from community contributors. Your help is valuable for making the book better for everyone.

**Dear [D2L contributors](https://github.com/d2l-ai/d2l-en/graphs/contributors), please email your GitHub ID and name to d2lbook.en@gmail.com so your name will appear on the [acknowledgments](https://d2l.ai/chapter_preface/index.html#Acknowledgments). Thanks.**


## License Summary

This open source book is made available under the Creative Commons Attribution-ShareAlike 4.0 International License. See [LICENSE](LICENSE) file.

The sample and reference code within this open source book is made available under a modified MIT license. See the [LICENSE-SAMPLECODE](LICENSE-SAMPLECODE) file.

[Chinese version](https://github.com/d2l-ai/d2l-zh) | [Discuss and report issues](https://discuss.d2l.ai/) | [Other Information](INFO.md)
